==> p6_namer-0.2.22-py3-none-any.whl: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.2.22 (2020-12-06)

### 0.2.21 (2020-12-05)

### 0.2.20 (2020-12-05)

### 0.2.19 (2020-12-04)

### 0.2.18 (2020-12-04)

### 0.2.17 (2020-12-04)

### 0.2.16 (2020-12-03)

### 0.2.15 (2020-12-02)

### 0.2.14 (2020-12-02)

### 0.2.13 (2020-12-02)

### 0.2.12 (2020-12-02)

### 0.2.11 (2020-12-02)

### 0.2.10 (2020-12-01)

### 0.2.9 (2020-12-01)

### 0.2.8 (2020-11-30)

### 0.2.7 (2020-11-30)

### 0.2.6 (2020-11-29)

### 0.2.5 (2020-11-29)


### Features

* **bundling:** minifies ([#119](https://github.com/p6m7g8/p6-namer/issues/119)) ([4af01a7](https://github.com/p6m7g8/p6-namer/commit/4af01a7985ad185080579a97f683aa12e4c8e9f2))

### 0.2.4 (2020-11-29)

### 0.2.3 (2020-11-29)


### Bug Fixes

* **lambdajs:** accounts for `aws/aws-cdk/pr/11729` ([#118](https://github.com/p6m7g8/p6-namer/issues/118)) ([d637c03](https://github.com/p6m7g8/p6-namer/commit/d637c0327c25ce0263580ab801506938182e94f8))

### 0.2.2 (2020-11-28)

### 0.2.1 (2020-11-27)


### Features

* **lambda:** converts from python to typescript ([#116](https://github.com/p6m7g8/p6-namer/issues/116)) ([44c6fbb](https://github.com/p6m7g8/p6-namer/commit/44c6fbb5fe68f7dcc4a6a72641e24190288652ad)), closes [#113](https://github.com/p6m7g8/p6-namer/issues/113)

## [0.2.0](https://github.com/p6m7g8/p6-namer/compare/v0.1.55...v0.2.0) (2020-11-27)

### [0.1.56](https://github.com/p6m7g8/p6-namer/compare/v0.1.55...v0.1.56) (2020-11-27)

### [0.1.56](https://github.com/p6m7g8/p6-namer/compare/v0.1.55...v0.1.56) (2020-11-27)

### 0.1.55 (2020-11-26)

### 0.1.54 (2020-11-25)

### 0.1.53 (2020-11-25)

### 0.1.52 (2020-11-24)

### 0.1.51 (2020-11-23)

### 0.1.50 (2020-11-20)

### 0.1.49 (2020-11-19)

### 0.1.48 (2020-11-18)

### 0.1.47 (2020-11-18)

### 0.1.46 (2020-11-18)

### 0.1.45 (2020-11-17)

### 0.1.44 (2020-11-17)

### 0.1.43 (2020-11-16)

### 0.1.42 (2020-11-15)

### 0.1.41 (2020-11-13)

### 0.1.40 (2020-11-12)

### 0.1.39 (2020-11-12)

### 0.1.38 (2020-11-12)

### 0.1.37 (2020-11-12)

### 0.1.36 (2020-11-11)

### 0.1.35 (2020-11-10)

### 0.1.34 (2020-11-10)

### 0.1.33 (2020-11-10)

### 0.1.32 (2020-11-09)

### 0.1.31 (2020-11-09)


### Features

* **codecov:** enables ([#63](https://github.com/p6m7g8/p6-namer/issues/63)) ([a9c700b](https://github.com/p6m7g8/p6-namer/commit/a9c700b3570a977434dc7558d95b89ce79e6fd7d))

### 0.1.30 (2020-11-09)

### 0.1.29 (2020-11-09)


### Features

* **CONTRIBUTING:** creates, updates README ([#62](https://github.com/p6m7g8/p6-namer/issues/62)) ([ce3d1a6](https://github.com/p6m7g8/p6-namer/commit/ce3d1a6c3fc48445237cd473a7c929b26afddb42))

### 0.1.28 (2020-11-09)


### Bug Fixes

* **README:** fixes Nuget badge ([#61](https://github.com/p6m7g8/p6-namer/issues/61)) ([aa28617](https://github.com/p6m7g8/p6-namer/commit/aa2861722be79c1a8ec575bf7fb64c1dd566067d))

### 0.1.27 (2020-11-09)

### 0.1.26 (2020-11-09)


### Features

* **nuget:** enables Nuget publishing (dotnet) ([#54](https://github.com/p6m7g8/p6-namer/issues/54)) ([b440179](https://github.com/p6m7g8/p6-namer/commit/b440179495441fe4e41b472b70758c6053c56fa1))

### 0.1.25 (2020-11-08)


### Bug Fixes

* **projen:** pending pr from projen, bumps constructs 3.0.4 to 3.2.0 ([#59](https://github.com/p6m7g8/p6-namer/issues/59)) ([42bc5f8](https://github.com/p6m7g8/p6-namer/commit/42bc5f83ddb6771295178a0e97a0d447a6edd666))

### 0.1.24 (2020-11-08)


### Features

* **CoC:** setups up Code of Conduct ([#58](https://github.com/p6m7g8/p6-namer/issues/58)) ([f42c304](https://github.com/p6m7g8/p6-namer/commit/f42c3045735fcf5d2237d1106149fe4462f7777e))

### 0.1.23 (2020-11-08)

### 0.1.22 (2020-11-08)

### 0.1.21 (2020-11-08)

### 0.1.20 (2020-11-08)


### Features

* **java:** enables maven publishing ([#53](https://github.com/p6m7g8/p6-namer/issues/53)) ([d9a1d5c](https://github.com/p6m7g8/p6-namer/commit/d9a1d5cbe43530c2b05dbdc3ec42c96ba640cddf))

### 0.1.19 (2020-11-08)


### Features

* **pypi:** enable pypi publishing ([#52](https://github.com/p6m7g8/p6-namer/issues/52)) ([9722017](https://github.com/p6m7g8/p6-namer/commit/97220177e809d27706209e43f57b717240326628))

### 0.1.18 (2020-11-08)

### 0.1.17 (2020-11-08)

### 0.1.16 (2020-11-08)

### 0.1.15 (2020-11-06)

### 0.1.14 (2020-11-05)

### 0.1.13 (2020-11-04)

### 0.1.12 (2020-11-03)

### 0.1.11 (2020-11-03)

### 0.1.10 (2020-11-03)

### 0.1.9 (2020-11-03)

### 0.1.8 (2020-11-02)

### 0.1.7 (2020-11-02)

### 0.1.6 (2020-11-02)

### 0.1.5 (2020-11-01)


### Features

* **README:** setups up badges, fixes usage ([#30](https://github.com/p6m7g8/p6-namer/issues/30)) ([2ce533c](https://github.com/p6m7g8/p6-namer/commit/2ce533ca54e7da6bf9940f986556fde6a7f9e363))

### 0.1.4 (2020-11-01)


### Features

* **projen:** enable auto projen upgrades ([#29](https://github.com/p6m7g8/p6-namer/issues/29)) ([23ff800](https://github.com/p6m7g8/p6-namer/commit/23ff800e4af0a2a1d91eaa1fb24214d18a89782b))

### 0.1.3 (2020-10-30)

### 0.1.2 (2020-10-30)

### 0.1.1 (2020-10-29)

## 0.1.0 (2020-10-28)


### ⚠ BREAKING CHANGES

* **api:** Introduces `accountAlias` via the `P6NamerProps` which is the only user tunable

### Features

* **api:** converts lambda to a custom resource and leverages crhelper ([#6](https://github.com/p6m7g8/p6-namer/issues/6)) ([49ff355](https://github.com/p6m7g8/p6-namer/commit/49ff35568abb4febfdeda2c576167c82e9290f89))

### 0.0.8 (2020-10-22)

### 0.0.7 (2020-10-21)

### 0.0.6 (2020-10-20)

### 0.0.5 (2020-10-19)


### Bug Fixes

* **demo:** sets a quicky change for demo ([#5](https://github.com/p6m7g8/p6-namer/issues/5)) ([5f77c81](https://github.com/p6m7g8/p6-namer/commit/5f77c81723f6cad1464762b47cc703b29c540cc9))

### 0.0.4 (2020-10-19)

### 0.0.3 (2020-10-18)


### Bug Fixes

* **README:** fixes typo Acount -> Account ([#3](https://github.com/p6m7g8/p6-namer/issues/3)) ([71c1124](https://github.com/p6m7g8/p6-namer/commit/71c11249cff925bafab32f29e73bf761b9133c46))

### 0.0.2 (2020-10-18)

### 0.0.1 (2020-10-18)


### Features

* **init:** adds the lambda ([d236a6b](https://github.com/p6m7g8/p6-namer/commit/d236a6b7c7a923ec82b9987c2019d856ce141cb0))

==> p6_namer-0.3.3-py3-none-any.whl: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### 0.3.3 (2020-12-21)

### 0.3.2 (2020-12-20)

### 0.3.1 (2020-12-20)

### 0.2.47 (2020-12-20)

### 0.2.46 (2020-12-19)


### Features

* **gitpod:** enables Gitpod via `projen` ([#195](https://github.com/p6m7g8/p6-namer/issues/195)) ([7ebfe34](https://github.com/p6m7g8/p6-namer/commit/7ebfe34003bf5e4a409ed8faaf15fc3331c51acd))

### 0.2.45 (2020-12-19)

### 0.2.44 (2020-12-18)

### 0.2.43 (2020-12-18)

### 0.2.42 (2020-12-17)

### 0.2.41 (2020-12-17)

### 0.2.40 (2020-12-17)

### 0.2.39 (2020-12-16)

### 0.2.38 (2020-12-16)

### 0.2.37 (2020-12-16)

### 0.2.36 (2020-12-16)

### 0.2.35 (2020-12-16)


### Features

* **java:** enable publishing to maven central ([#182](https://github.com/p6m7g8/p6-namer/issues/182)) ([3d55342](https://github.com/p6m7g8/p6-namer/commit/3d55342804392b61c79e57c3275941464e214761))

### 0.2.34 (2020-12-16)

### 0.2.33 (2020-12-16)

### 0.2.32 (2020-12-15)

### 0.2.31 (2020-12-14)

### 0.2.30 (2020-12-14)

### 0.2.29 (2020-12-11)

### 0.2.28 (2020-12-11)

### 0.2.27 (2020-12-10)

### 0.2.26 (2020-12-09)

### 0.2.25 (2020-12-08)

### 0.2.24 (2020-12-07)

### 0.2.23 (2020-12-07)

### 0.2.22 (2020-12-06)

### 0.2.21 (2020-12-05)

### 0.2.20 (2020-12-05)

### 0.2.19 (2020-12-04)

### 0.2.18 (2020-12-04)

### 0.2.17 (2020-12-04)

### 0.2.16 (2020-12-03)

### 0.2.15 (2020-12-02)

### 0.2.14 (2020-12-02)

### 0.2.13 (2020-12-02)

### 0.2.12 (2020-12-02)

### 0.2.11 (2020-12-02)

### 0.2.10 (2020-12-01)

### 0.2.9 (2020-12-01)

### 0.2.8 (2020-11-30)

### 0.2.7 (2020-11-30)

### 0.2.6 (2020-11-29)

### 0.2.5 (2020-11-29)


### Features

* **bundling:** minifies ([#119](https://github.com/p6m7g8/p6-namer/issues/119)) ([4af01a7](https://github.com/p6m7g8/p6-namer/commit/4af01a7985ad185080579a97f683aa12e4c8e9f2))

### 0.2.4 (2020-11-29)

### 0.2.3 (2020-11-29)


### Bug Fixes

* **lambdajs:** accounts for `aws/aws-cdk/pr/11729` ([#118](https://github.com/p6m7g8/p6-namer/issues/118)) ([d637c03](https://github.com/p6m7g8/p6-namer/commit/d637c0327c25ce0263580ab801506938182e94f8))

### 0.2.2 (2020-11-28)

### 0.2.1 (2020-11-27)


### Features

* **lambda:** converts from python to typescript ([#116](https://github.com/p6m7g8/p6-namer/issues/116)) ([44c6fbb](https://github.com/p6m7g8/p6-namer/commit/44c6fbb5fe68f7dcc4a6a72641e24190288652ad)), closes [#113](https://github.com/p6m7g8/p6-namer/issues/113)

## [0.2.0](https://github.com/p6m7g8/p6-namer/compare/v0.1.55...v0.2.0) (2020-11-27)

### [0.1.56](https://github.com/p6m7g8/p6-namer/compare/v0.1.55...v0.1.56) (2020-11-27)

### [0.1.56](https://github.com/p6m7g8/p6-namer/compare/v0.1.55...v0.1.56) (2020-11-27)

### 0.1.55 (2020-11-26)

### 0.1.54 (2020-11-25)

### 0.1.53 (2020-11-25)

### 0.1.52 (2020-11-24)

### 0.1.51 (2020-11-23)

### 0.1.50 (2020-11-20)

### 0.1.49 (2020-11-19)

### 0.1.48 (2020-11-18)

### 0.1.47 (2020-11-18)

### 0.1.46 (2020-11-18)

### 0.1.45 (2020-11-17)

### 0.1.44 (2020-11-17)

### 0.1.43 (2020-11-16)

### 0.1.42 (2020-11-15)

### 0.1.41 (2020-11-13)

### 0.1.40 (2020-11-12)

### 0.1.39 (2020-11-12)

### 0.1.38 (2020-11-12)

### 0.1.37 (2020-11-12)

### 0.1.36 (2020-11-11)

### 0.1.35 (2020-11-10)

### 0.1.34 (2020-11-10)

### 0.1.33 (2020-11-10)

### 0.1.32 (2020-11-09)

### 0.1.31 (2020-11-09)


### Features

* **codecov:** enables ([#63](https://github.com/p6m7g8/p6-namer/issues/63)) ([a9c700b](https://github.com/p6m7g8/p6-namer/commit/a9c700b3570a977434dc7558d95b89ce79e6fd7d))

### 0.1.30 (2020-11-09)

### 0.1.29 (2020-11-09)


### Features

* **CONTRIBUTING:** creates, updates README ([#62](https://github.com/p6m7g8/p6-namer/issues/62)) ([ce3d1a6](https://github.com/p6m7g8/p6-namer/commit/ce3d1a6c3fc48445237cd473a7c929b26afddb42))

### 0.1.28 (2020-11-09)


### Bug Fixes

* **README:** fixes Nuget badge ([#61](https://github.com/p6m7g8/p6-namer/issues/61)) ([aa28617](https://github.com/p6m7g8/p6-namer/commit/aa2861722be79c1a8ec575bf7fb64c1dd566067d))

### 0.1.27 (2020-11-09)

### 0.1.26 (2020-11-09)


### Features

* **nuget:** enables Nuget publishing (dotnet) ([#54](https://github.com/p6m7g8/p6-namer/issues/54)) ([b440179](https://github.com/p6m7g8/p6-namer/commit/b440179495441fe4e41b472b70758c6053c56fa1))

### 0.1.25 (2020-11-08)


### Bug Fixes

* **projen:** pending pr from projen, bumps constructs 3.0.4 to 3.2.0 ([#59](https://github.com/p6m7g8/p6-namer/issues/59)) ([42bc5f8](https://github.com/p6m7g8/p6-namer/commit/42bc5f83ddb6771295178a0e97a0d447a6edd666))

### 0.1.24 (2020-11-08)


### Features

* **CoC:** setups up Code of Conduct ([#58](https://github.com/p6m7g8/p6-namer/issues/58)) ([f42c304](https://github.com/p6m7g8/p6-namer/commit/f42c3045735fcf5d2237d1106149fe4462f7777e))

### 0.1.23 (2020-11-08)

### 0.1.22 (2020-11-08)

### 0.1.21 (2020-11-08)

### 0.1.20 (2020-11-08)


### Features

* **java:** enables maven publishing ([#53](https://github.com/p6m7g8/p6-namer/issues/53)) ([d9a1d5c](https://github.com/p6m7g8/p6-namer/commit/d9a1d5cbe43530c2b05dbdc3ec42c96ba640cddf))

### 0.1.19 (2020-11-08)


### Features

* **pypi:** enable pypi publishing ([#52](https://github.com/p6m7g8/p6-namer/issues/52)) ([9722017](https://github.com/p6m7g8/p6-namer/commit/97220177e809d27706209e43f57b717240326628))

### 0.1.18 (2020-11-08)

### 0.1.17 (2020-11-08)

### 0.1.16 (2020-11-08)

### 0.1.15 (2020-11-06)

### 0.1.14 (2020-11-05)

### 0.1.13 (2020-11-04)

### 0.1.12 (2020-11-03)

### 0.1.11 (2020-11-03)

### 0.1.10 (2020-11-03)

### 0.1.9 (2020-11-03)

### 0.1.8 (2020-11-02)

### 0.1.7 (2020-11-02)

### 0.1.6 (2020-11-02)

### 0.1.5 (2020-11-01)


### Features

* **README:** setups up badges, fixes usage ([#30](https://github.com/p6m7g8/p6-namer/issues/30)) ([2ce533c](https://github.com/p6m7g8/p6-namer/commit/2ce533ca54e7da6bf9940f986556fde6a7f9e363))

### 0.1.4 (2020-11-01)


### Features

* **projen:** enable auto projen upgrades ([#29](https://github.com/p6m7g8/p6-namer/issues/29)) ([23ff800](https://github.com/p6m7g8/p6-namer/commit/23ff800e4af0a2a1d91eaa1fb24214d18a89782b))

### 0.1.3 (2020-10-30)

### 0.1.2 (2020-10-30)

### 0.1.1 (2020-10-29)

## 0.1.0 (2020-10-28)


### ⚠ BREAKING CHANGES

* **api:** Introduces `accountAlias` via the `P6NamerProps` which is the only user tunable

### Features

* **api:** converts lambda to a custom resource and leverages crhelper ([#6](https://github.com/p6m7g8/p6-namer/issues/6)) ([49ff355](https://github.com/p6m7g8/p6-namer/commit/49ff35568abb4febfdeda2c576167c82e9290f89))

### 0.0.8 (2020-10-22)

### 0.0.7 (2020-10-21)

### 0.0.6 (2020-10-20)

### 0.0.5 (2020-10-19)


### Bug Fixes

* **demo:** sets a quicky change for demo ([#5](https://github.com/p6m7g8/p6-namer/issues/5)) ([5f77c81](https://github.com/p6m7g8/p6-namer/commit/5f77c81723f6cad1464762b47cc703b29c540cc9))

### 0.0.4 (2020-10-19)

### 0.0.3 (2020-10-18)


### Bug Fixes

* **README:** fixes typo Acount -> Account ([#3](https://github.com/p6m7g8/p6-namer/issues/3)) ([71c1124](https://github.com/p6m7g8/p6-namer/commit/71c11249cff925bafab32f29e73bf761b9133c46))

### 0.0.2 (2020-10-18)

### 0.0.1 (2020-10-18)


### Features

* **init:** adds the lambda ([d236a6b](https://github.com/p6m7g8/p6-namer/commit/d236a6b7c7a923ec82b9987c2019d856ce141cb0))
